@@ -15,13 +15,15 @@ public:
     ~TodoEditDialog();
 
     void setDue(QDate due);
+    void setCalendar(int calendarId);
 
 private:
     Ui::TodoEditDialog *ui;
 
     CTodo *todo;
 
-    bool defaultDue;
+    bool saveDefaults;
+    bool saveDue;
 
 private slots:
     void onDateChanged();
