@@ -413,21 +413,29 @@ journée</translation>
 <context>
     <name>DatePickDialog</name>
     <message>
-        <location filename="../DatePickDialog.cpp" line="27"/>
-        <source>Done</source>
-        <translation>Effectué</translation>
+        <location filename="../DatePickDialog.cpp" line="16"/>
+        <source>Today</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DatePickDialog.cpp" line="181"/>
+        <location filename="../DatePickDialog.cpp" line="161"/>
         <source>Week %1 (%2 - %3)</source>
         <translation>Semaine %1 (%2 - %3)</translation>
     </message>
     <message>
-        <location filename="../DatePickDialog.ui" line="6"/>
+        <location filename="../DatePickDialog.cpp" line="19"/>
         <source>Select date</source>
         <translation>Choisir la date</translation>
     </message>
 </context>
+<context>
+    <name>DateTimePickDialog</name>
+    <message>
+        <location filename="../DateTimePickDialog.cpp" line="15"/>
+        <source>Done</source>
+        <translation>Effectué</translation>
+    </message>
+</context>
 <context>
     <name>DayNumberDialog</name>
     <message>
@@ -1049,6 +1057,19 @@ journée</translation>
         </translation>
     </message>
 </context>
+<context>
+    <name>TimePickDialog</name>
+    <message>
+        <location filename="../TimePickDialog.cpp" line="11"/>
+        <source>Now</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../TimePickDialog.cpp" line="13"/>
+        <source>Select time</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>TodoEditDialog</name>
     <message>
