@@ -417,21 +417,29 @@ dzień</translation>
 <context>
     <name>DatePickDialog</name>
     <message>
-        <location filename="../DatePickDialog.cpp" line="27"/>
-        <source>Done</source>
-        <translation>Gotowe</translation>
+        <location filename="../DatePickDialog.cpp" line="16"/>
+        <source>Today</source>
+        <translation>Dzisiaj</translation>
     </message>
     <message>
-        <location filename="../DatePickDialog.cpp" line="181"/>
+        <location filename="../DatePickDialog.cpp" line="161"/>
         <source>Week %1 (%2 - %3)</source>
         <translation>Tydzień %1 (%2 - %3)</translation>
     </message>
     <message>
-        <location filename="../DatePickDialog.ui" line="6"/>
+        <location filename="../DatePickDialog.cpp" line="19"/>
         <source>Select date</source>
         <translation>Wybierz datę</translation>
     </message>
 </context>
+<context>
+    <name>DateTimePickDialog</name>
+    <message>
+        <location filename="../DateTimePickDialog.cpp" line="15"/>
+        <source>Done</source>
+        <translation>Gotowe</translation>
+    </message>
+</context>
 <context>
     <name>DayNumberDialog</name>
     <message>
@@ -1062,6 +1070,19 @@ dzień</translation>
         </translation>
     </message>
 </context>
+<context>
+    <name>TimePickDialog</name>
+    <message>
+        <location filename="../TimePickDialog.cpp" line="11"/>
+        <source>Now</source>
+        <translation>Teraz</translation>
+    </message>
+    <message>
+        <location filename="../TimePickDialog.cpp" line="13"/>
+        <source>Select time</source>
+        <translation>Wybierz czas</translation>
+    </message>
+</context>
 <context>
     <name>TodoEditDialog</name>
     <message>
